"""
Submodule of `domed` that declares all the standard HTML tags.
Tag names that are reserved words in Python have an underscore appended.
Thus, del becomes del_, input becomes input_, and set becomes set_.
"""

from domed import create_tag

a = create_tag("a")
abbr = create_tag("abbr")
acronym = create_tag("acronym")
address = create_tag("address")
applet = create_tag("applet")
area = create_tag("area")
article = create_tag("article")
aside = create_tag("aside")
audio = create_tag("audio")
b = create_tag("b")
base = create_tag("base")
basefont = create_tag("basefont")
bdi = create_tag("bdi")
bdo = create_tag("bdo")
big = create_tag("big")
blockquote = create_tag("blockquote")
body = create_tag("body")
br = create_tag("br")
button = create_tag("button")
canvas = create_tag("canvas")
caption = create_tag("caption")
center = create_tag("center")
cite = create_tag("cite")
code = create_tag("code")
col = create_tag("col")
colgroup = create_tag("colgroup")
data = create_tag("data")
datalist = create_tag("datalist")
dd = create_tag("dd")
del_ = create_tag("del")
details = create_tag("details")
dfn = create_tag("dfn")
dialog = create_tag("dialog")
dir = create_tag("dir")
div = create_tag("div")
dl = create_tag("dl")
dt = create_tag("dt")
em = create_tag("em")
embed = create_tag("embed")
fieldset = create_tag("fieldset")
figcaption = create_tag("figcaption")
figure = create_tag("figure")
font = create_tag("font")
footer = create_tag("footer")
form = create_tag("form")
frame = create_tag("frame")
frameset = create_tag("frameset")
h1 = create_tag("h1")
h2 = create_tag("h2")
h3 = create_tag("h3")
h4 = create_tag("h4")
h5 = create_tag("h5")
h6 = create_tag("h6")
head = create_tag("head")
header = create_tag("header")
hr = create_tag("hr")
html = create_tag("html")
i = create_tag("i")
iframe = create_tag("iframe")
img = create_tag("img")
input_ = create_tag("input")
ins = create_tag("ins")
kbd = create_tag("kbd")
label = create_tag("label")
legend = create_tag("legend")
li = create_tag("li")
link = create_tag("link")
main = create_tag("main")
map = create_tag("map")
mark = create_tag("mark")
meta = create_tag("meta")
meter = create_tag("meter")
nav = create_tag("nav")
noframes = create_tag("noframes")
noscript = create_tag("noscript")
object = create_tag("object")
ol = create_tag("ol")
optgroup = create_tag("optgroup")
option = create_tag("option")
output = create_tag("output")
p = create_tag("p")
param = create_tag("param")
picture = create_tag("picture")
pre = create_tag("pre")
progress = create_tag("progress")
q = create_tag("q")
rp = create_tag("rp")
rt = create_tag("rt")
ruby = create_tag("ruby")
s = create_tag("s")
samp = create_tag("samp")
script = create_tag("script")
section = create_tag("section")
select = create_tag("select")
set_ = create_tag("set")
small = create_tag("small")
source = create_tag("source")
span = create_tag("span")
strike = create_tag("strike")
strong = create_tag("strong")
style = create_tag("style")
sub = create_tag("sub")
summary = create_tag("summary")
sup = create_tag("sup")
svg = create_tag("svg")
table = create_tag("table")
tbody = create_tag("tbody")
td = create_tag("td")
template = create_tag("template")
textarea = create_tag("textarea")
tfoot = create_tag("tfoot")
th = create_tag("th")
thead = create_tag("thead")
time = create_tag("time")
title = create_tag("title")
tr = create_tag("tr")
track = create_tag("track")
tt = create_tag("tt")
u = create_tag("u")
ul = create_tag("ul")
var = create_tag("var")
video = create_tag("video")
wbr = create_tag("wbr")