"""
Submodule of `domed` that declares all the standard SVG tags.
Hyphens in the tag names are replaced by underscore in the Python variable name.
For example, the SVG tag `font-face` becomes `font_face` in Python.
"""

from domed import create_tag

svg_namespace = "http://www.w3.org/2000/svg"

altGlyph = create_tag("altGlyph", svg_namespace)
altGlyphDef = create_tag("altGlyphDef", svg_namespace)
altGlyphItem = create_tag("altGlyphItem", svg_namespace)
animate = create_tag("animate", svg_namespace)
animateColor = create_tag("animateColor", svg_namespace)
animateMotion = create_tag("animateMotion", svg_namespace)
animateTransform = create_tag("animateTransform", svg_namespace)
circle = create_tag("circle", svg_namespace)
clipPath = create_tag("clipPath", svg_namespace)
color_profile = create_tag("color-profile", svg_namespace)
cursor = create_tag("cursor", svg_namespace)
defs = create_tag("defs", svg_namespace)
desc = create_tag("desc", svg_namespace)
ellipse = create_tag("ellipse", svg_namespace)
feBlend = create_tag("feBlend", svg_namespace)
feColorMatrix = create_tag("feColorMatrix", svg_namespace)
feComponentTransfer = create_tag("feComponentTransfer", svg_namespace)
feComposite = create_tag("feComposite", svg_namespace)
feConvolveMatrix = create_tag("feConvolveMatrix", svg_namespace)
feDiffuseLighting = create_tag("feDiffuseLighting", svg_namespace)
feDisplacementMap = create_tag("feDisplacementMap", svg_namespace)
feDistantLight = create_tag("feDistantLight", svg_namespace)
feFlood = create_tag("feFlood", svg_namespace)
feFuncA = create_tag("feFuncA", svg_namespace)
feFuncB = create_tag("feFuncB", svg_namespace)
feFuncG = create_tag("feFuncG", svg_namespace)
feFuncR = create_tag("feFuncR", svg_namespace)
feGaussianBlur = create_tag("feGaussianBlur", svg_namespace)
feImage = create_tag("feImage", svg_namespace)
feMerge = create_tag("feMerge", svg_namespace)
feMergeNode = create_tag("feMergeNode", svg_namespace)
feMorphology = create_tag("feMorphology", svg_namespace)
feOffset = create_tag("feOffset", svg_namespace)
fePointLight = create_tag("fePointLight", svg_namespace)
feSpecularLighting = create_tag("feSpecularLighting", svg_namespace)
feSpotLight = create_tag("feSpotLight", svg_namespace)
feTile = create_tag("feTile", svg_namespace)
feTurbulence = create_tag("feTurbulence", svg_namespace)
filter = create_tag("filter", svg_namespace)
font = create_tag("font", svg_namespace)
font_face = create_tag("font-face", svg_namespace)
font_face_format = create_tag("font-face-format", svg_namespace)
font_face_name = create_tag("font-face-name", svg_namespace)
font_face_src = create_tag("font-face-src", svg_namespace)
font_face_uri = create_tag("font-face-uri", svg_namespace)
foreignObject = create_tag("foreignObject", svg_namespace)
g = create_tag("g", svg_namespace)
glyph = create_tag("glyph", svg_namespace)
glyphRef = create_tag("glyphRef", svg_namespace)
hkern = create_tag("hkern", svg_namespace)
image = create_tag("image", svg_namespace)
line = create_tag("line", svg_namespace)
linearGradient = create_tag("linearGradient", svg_namespace)
marker = create_tag("marker", svg_namespace)
mask = create_tag("mask", svg_namespace)
metadata = create_tag("metadata", svg_namespace)
missing_glyph = create_tag("missing-glyph", svg_namespace)
mpath = create_tag("mpath", svg_namespace)
path = create_tag("path", svg_namespace)
pattern = create_tag("pattern", svg_namespace)
polygon = create_tag("polygon", svg_namespace)
polyline = create_tag("polyline", svg_namespace)
radialGradient = create_tag("radialGradient", svg_namespace)
rect = create_tag("rect", svg_namespace)
solidColor = create_tag("solidColor", svg_namespace)
stop = create_tag("stop", svg_namespace)
style = create_tag("style", svg_namespace)
svg = create_tag("svg", svg_namespace)
switch = create_tag("switch", svg_namespace)
symbol = create_tag("symbol", svg_namespace)
text = create_tag("text", svg_namespace)
textPath = create_tag("textPath", svg_namespace)
title = create_tag("title", svg_namespace)
tref = create_tag("tref", svg_namespace)
tspan = create_tag("tspan", svg_namespace)
use = create_tag("use", svg_namespace)
view = create_tag("view", svg_namespace)
vkern = create_tag("vkern", svg_namespace)